@@ -550,7 +550,7 @@ process_copy_in ()
 		long_format (&file_hdr, (char *) 0);
 	    }
 	  else
-	    printf ("%s\n", file_hdr.c_name);
+	    printf ("%s%c", file_hdr.c_name, name_end);
 
 	  crc = 0;
 	  tape_toss_input (in_file_des, file_hdr.c_filesize);
