@@ -399,7 +399,11 @@ process_copy_out ()
 		{
 		  times.actime = file_stat.st_atime;
 		  times.modtime = file_stat.st_mtime;
-		  if (utime (file_hdr.c_name, &times) < 0)
+		  /* Silently ignore EROFS because reading the file
+                     won't have upset its timestamp if it's on a
+                     read-only filesystem */
+		  if (utime (file_hdr.c_name, &times) < 0
+		      && errno != EROFS)
 		    error (0, errno, "%s", file_hdr.c_name);
 		}
 	      break;
@@ -800,7 +804,11 @@ writeout_defered_file (header, out_file_des)
     {
       times.actime = file_hdr.c_mtime;
       times.modtime = file_hdr.c_mtime;
-      if (utime (file_hdr.c_name, &times) < 0)
+      /* Silently ignore EROFS because reading the file
+	 won't have upset its timestamp if it's on a
+	 read-only filesystem */
+      if (utime (file_hdr.c_name, &times) < 0
+	  && errno != EROFS)
 	error (0, errno, "%s", file_hdr.c_name);
     }
   return;
