@@ -190,9 +190,14 @@ process_copy_pass ()
 		{
 		  times.actime = in_file_stat.st_atime;
 		  times.modtime = in_file_stat.st_mtime;
-		  if (utime (input_name.ds_string, &times) < 0)
+		  /* Silently ignore EROFS because reading the file
+		     won't have upset its timestamp if it's on a
+		     read-only filesystem */
+		  if (utime (input_name.ds_string, &times) < 0
+		      && errno != EROFS)
 		    error (0, errno, "%s", input_name.ds_string);
-		  if (utime (output_name.ds_string, &times) < 0)
+		  if (utime (output_name.ds_string, &times) < 0
+		      && errno != EROFS)
 		    error (0, errno, "%s", output_name.ds_string);
 		}
 	      if (retain_time_flag)
